import { useState, useEffect } from 'react';

import { getFirstDatabase } from 'src/db';
import { getData } from 'src/modules/map/regionData';
import { DbRegion } from './types';

const useRegionData = (regionId: number) => {
  const [regionData, setRegionData] = useState<DbRegion | null>(null);
  const [avatars, setAvatars] = useState<string[] | null>(null);

  useEffect(() => {
    const fetchRegionData = async () => {
      const db = getFirstDatabase();
      try {
        await getData(db, regionId, 'regions', (data, avatars) => {
          setRegionData(data);
          setAvatars(avatars);
        });
      } catch (error) {
        console.error('Error fetching region data', error);
      }
    };

    fetchRegionData();
  }, [regionId]);

  return { regionData, avatars };
};

export default useRegionData;
